@@ -1,5 +1,5 @@
 package Net::FreeIPA::DummyLogger;
-$Net::FreeIPA::DummyLogger::VERSION = '0.0.2';
+$Net::FreeIPA::DummyLogger::VERSION = '0.0.5';
 use strict;
 use warnings;
 
@@ -27,7 +27,7 @@ sub new
 
 # Mock basic methods of Log4Perl getLogger instance
 no strict 'refs'; ## no critic
-foreach my $i (qw(error warn info verbose debug)) {
+foreach my $i (qw(error warn info debug)) {
     *{$i} = sub {}
 }
 use strict 'refs';
