@@ -1,5 +1,5 @@
 package Net::FreeIPA::RPC;
-$Net::FreeIPA::RPC::VERSION = '0.0.2';
+$Net::FreeIPA::RPC::VERSION = '0.0.5';
 use strict;
 use warnings;
 
@@ -8,6 +8,8 @@ use Readonly;
 use REST::Client;
 use JSON::XS;
 
+use Net::FreeIPA::Error;
+
 use LWP::UserAgent;
 # Add kerberos support
 use LWP::Authen::Negotiate;
@@ -121,11 +123,15 @@ sub new_client
         $self->{json}->canonical(1); # sort the keys, to create reproducable results
         $self->set_api_version('API');
 
+        # Reset error atrribute (will be adapted by rpc method)
+        $self->{error} = mkerror();
         return 1;
     } else {
         $content = '<undef>' if ! defined($content);
         # Do no print possible password
         $self->error("Login failed (url $url$login_url code $code): $content");
+        # Set error attribute
+        $self->{error} = mkerror({message => "Login failed (url $url$login_url code $code)"});
         return;
     }
 }
@@ -211,14 +217,18 @@ sub post
 
     my $ret;
     if ($code == 200) {
-        $ans = decode_json($content);
+        $ans = $self->{json}->decode($content);
         $self->debug("Successful JSON POST".($self->{debugapi} ? " JSON $content" : ""));
         $ret = 1;
+        # Reset error atrribute (will be adapted by rpc method)
+        $self->{error} = mkerror();
     } else {
         $ans = $content;
 
         $content = '<undef>' if ! defined($content);
         $self->error("POST failed (url $IPA_URL_JSON code $code): $content");
+        # Set error (not processed anymore by rpc)
+        $self->{error} = mkerror({message => "POST failed (url $IPA_URL_JSON code $code)"});
     }
 
     # Store last (decoded) answer in answer attribute
@@ -253,6 +263,11 @@ Options
 A path-like string, indicating which subtree of the decoided JSON response
 should be set as result attribute (default C<result/result>).
 
+=item noerror
+
+An array ref with errorcodes or errornames that are not reported as an error.
+(Still return C<undef>).
+
 =back
 
 Processed result is stored in the result attribute.
@@ -261,9 +276,9 @@ Processed result is stored in the result attribute.
 
 sub rpc
 {
-    my ($self, $command, $args, $opts, $result_path) = @_;
+    my ($self, $command, $args, $opts, %opts) = @_;
 
-    $result_path = 'result/result' if (! defined($result_path));
+    my $result_path = $opts{result_path} || 'result/result';
 
     # Reset any previous result
     $self->{result} = undef;
@@ -272,13 +287,21 @@ sub rpc
 
     my $ret;
 
-    my $error = $self->{answer}->{error};
+    my $error = mkerror($self->{answer}->{error});
+
+    # Save error attribute
+    $self->{error} = $error;
+
     if ($error) {
-        $self->error("post got error (".$self->{json}->encode($error).")");
+        my @noerrors = grep {$error == $_} @{$opts{noerror} || []};
+
+        my $error_method = @noerrors ? 'debug' : 'error';
+
+        $self->$error_method("$command got error ($error)");
     } else {
         $ret = 1;
 
-        $self->warn("rpc got truncated result") if $self->{answer}->{result}->{truncated};
+        $self->warn("$command got truncated result") if $self->{answer}->{result}->{truncated};
 
         my $res = $self->{answer};
         # remove any "empty" paths
@@ -306,7 +329,7 @@ sub get_api_commands
 {
     my ($self) = @_;
 
-    return $self->rpc('json_metadata', [], {command => "all"}, 'result/commands') ? $self->{result} : undef;
+    return $self->rpc('json_metadata', [], {command => "all"}, result_path => 'result/commands') ? $self->{result} : undef;
 }
 
 
@@ -329,7 +352,7 @@ sub get_api_version
 {
     my ($self) = @_;
 
-    return $self->rpc('env', ['api_version'], {}, 'result/result/api_version') ? $self->{result} : undef;
+    return $self->rpc('env', ['api_version'], {}, result_path => 'result/result/api_version') ? $self->{result} : undef;
 }
 
 =pod
